@@ -1,4 +1,4 @@
 """Module to calculate Universal Thermal Climate Index."""
 
 from .tmrt import mean_radiant_temperature  # noqa: F401
-from .utci import saturation_specific_humidity, utci  # noqa: F401
+from .utci import universal_thermal_climate_index  # noqa: F401
